@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2008, Parallels, Inc. All rights reserved.
+ *  Copyright (C) 2000-2009, Parallels, Inc. All rights reserved.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@
  *	    0 - no
  *	  < 0 - error
  */
-int vz_fs_is_mounted(char *root)
+int vz_fs_is_mounted(const char *root)
 {
 	FILE *fp;
 	char buf[512];
